@@ -49,7 +49,7 @@ describe 'designate::client' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           { :client_package_name => 'python3-designateclient' }
         when 'RedHat'
