@@ -100,7 +100,7 @@ describe 'designate::worker' do
       end
 
       let(:platform_params) do
-        case facts[:osfamily]
+        case facts[:os]['family']
         when 'Debian'
           {
             :worker_package_name => 'designate-worker',
